@@ -50,7 +50,7 @@ void SelectionTypeTreeWidgetTest::shouldLoadTemplate()
     QFETCH(QString, filename);
     QFETCH(int, topLevelItems);
 
-    QString fileNameFullPath = QLatin1String(PIMDATAEXPORTER_DATA_DIR) + QLatin1String("/") + filename;
+    QString fileNameFullPath = QLatin1StringView(PIMDATAEXPORTER_DATA_DIR) + QLatin1StringView("/") + filename;
     QFile f(fileNameFullPath);
     QVERIFY(f.exists());
     SelectionTypeTreeWidget w(true);
